@@ -1,6 +1,7 @@
-import atexit
+# import atexit
 import os
 import sys
+import urllib.parse
 import uuid
 from types import FunctionType
 
@@ -134,7 +135,7 @@ class App:
         :param start_response:
         :return:
         """
-        from .http import HttpServerError, HttpNotFound
+        from .http import ServerError, NotFound as NewNotFound
 
         request = None
         response = None
@@ -153,19 +154,20 @@ class App:
             elif endpoint in self._custom_url_map:
                 response = self._custom_url_map[endpoint](request, **values)
             else:
-                response = HttpNotFound()
+                response = NewNotFound()
         except Exception as e:
-            if isinstance(e, NotFound):
-                response = HttpNotFound()
-            elif self.config.debug:
-                response = HttpServerError(e)
-            else:
-                response = HttpServerError()
-
-            msg = str(e)
+            msg = '\n\t'.join(e.args)
             if request:
-                msg += ':' + request.path
+                msg = 'Error occured during handle request %r:\n\t%s' % (request.path, msg)
+
             self._logger.warning(msg)
+
+            if isinstance(e, NotFound):
+                response = NewNotFound()
+            elif self.config.debug:
+                response = ServerError(msg.replace('<', '&lt;').replace('>', '&gt;'))
+            else:
+                response = ServerError()
         finally:
             self.config.middleware_manager.handle_leaving(request, response)
             request.context().pop()
