@@ -21,26 +21,36 @@ class JsonResponse(HttpResponse):
 
 
 class FileResponse(HttpResponse):
-    def __init__(self, fp: Union[str, IO], attachment: str = None,
-                 content_type='application/octet-stream',
+    def __init__(self, fp: Union[str, bytes, IO], attachment: str = None,
+                 content_type=None,
                  ranges: Tuple[int, int] = (),
                  request=None, **kwargs):
         """
 
-        :param fp:
+        :param fp: 文件名或内容。如果指定的 fp 是文件名（字符串），那么认为返回的是文件名。
+        如果需要返回的内容是字符串，那么需要先处理成 bytes
         :param attachment: 指定一个字符串，作为返回附件的文件名
-        :param content_type:
+        :param content_type: 当未指定此值时，如果指定的 fp 是文件名，那么会自动根据文件的扩展名进行识别
         :param ranges: 用于指定返回数据的分块起始位置
         :param kwargs:
         """
         # 如果是字符串，就认为是文件路径
         if isinstance(fp, str):
+            # 根据文件的扩展名自动识别 mime
+            if content_type is None:
+                import mimetypes
+                (content_type, _) = mimetypes.guess_type(fp)
             self.fp = open(fp, mode='rb')
         else:
             self.fp = fp
 
+        if content_type is None:
+            content_type = 'application/octet-stream'
+
         # 需要分块返回文件
         if ranges:
+            if not isinstance(fp, IO):
+                raise TypeError('FileResponse with "ranges" works with type "IO" only')
             if not self._get_file_chunk(ranges, kwargs):
                 super(FileResponse, self).__init__(status=416)
                 return
@@ -74,8 +84,7 @@ class FileResponse(HttpResponse):
         else:
             chunk = BytesIO()
             # The fetched data size
-            # -1: avoid to fetch the file end unexpected
-            chunk_size = end - start - 1
+            chunk_size = end - start
             self.fp.seek(start)
             buffer = self.fp.read(chunk_size)
             self.fp.close()
@@ -123,30 +132,30 @@ class FileResponse(HttpResponse):
         headers['Content-Disposition'] = 'attachment;filename=%s' % filename
 
 
-class HttpBadRequest(HttpResponse):
+class BadRequest(HttpResponse):
     def __init__(self, content=None, **kwargs):
         super().__init__(content, status=400, **kwargs)
 
 
-class HttpRedirect(HttpResponse):
+class Redirect(HttpResponse):
     def __init__(self, location, status=302, **kwargs):
         super().__init__(None, status=status, headers={
             'Location': escape(location)
         }, **kwargs)
 
 
-class HttpUnauthorized(HttpResponse):
+class Unauthorized(HttpResponse):
     def __init__(self, content=None, **kwargs):
         super().__init__(content, status=401, **kwargs)
 
 
-class HttpNotFound(HttpResponse):
+class NotFound(HttpResponse):
     def __init__(self, content=None, **kwargs):
         super().__init__(content, status=404, **kwargs)
 
 
-class HttpServerError(HttpResponse, InternalServerError):
+class ServerError(HttpResponse, InternalServerError):
     def __init__(self, content=None):
         if isinstance(content, Exception):
-            content = content.args[0]
+            content = content.args[0] if content.args else str(content)
         super().__init__(content, status=500, content_type='text/plain')
