@@ -1,26 +1,26 @@
 import os
 from typing import Dict, Optional
 
-from ..context import AppContext
-from ..http.response import HttpNotFound, HttpResponse
+from ..config import AppConfig
+from ..http.response import NotFound, HttpResponse
 from ..util import utils
 from ..util.func_util import FunctionDescription
 
 
 class RouteResolver:
-    def __init__(self, context: AppContext,
+    def __init__(self, config: AppConfig,
                  entry_cache: Dict[str, Optional[FunctionDescription]],
                  method: str,
                  entry: str):
-        self.context = context
+        self.config = config
         self.entry_cache = entry_cache
         self.entry = entry
         self.method = method.lower()
         from ..util import Logger
-        self.logger = Logger.get(context.app_id)
+        self.logger = Logger.get(config.app_id)
 
     def _get_module_abs_path(self, module_name):
-        abs_path = os.path.join(self.context.ROOT, module_name)
+        abs_path = os.path.join(self.config.ROOT, module_name)
 
         if os.path.isdir(abs_path):
             # 如果 module_name 是目录，那么就查找 __init__.py 是否存在
@@ -47,7 +47,7 @@ class RouteResolver:
         if module_name is None:
             self.logger.warning(
                 'Cannot find route "%s" in routes_map' % self.entry)
-            return HttpNotFound()
+            return NotFound()
 
         func_name = self.method
         module_path = module_name.replace('.', os.path.sep)
@@ -62,7 +62,7 @@ class RouteResolver:
             module_abs_path = self._get_module_abs_path(module_path)
 
             if module_abs_path is None:
-                return HttpNotFound()
+                return NotFound()
 
             module_name = module_abs_path.replace(os.path.sep, '.')
 
@@ -78,23 +78,23 @@ class RouteResolver:
         except Exception as e:
             message = 'Failed to load entry "%s": %s' % (self.entry, fullname)
             self.logger.error(message, e)
-            return HttpNotFound()
+            return NotFound()
 
         # 检查 extname 是否一致
         if isinstance(desc, FunctionDescription) and desc.decorator['extname'] != extname:
             message = 'Failed to load entry "%s": extname "%s" is not exactly match with "%s"' % (
                 self.entry, extname, desc.decorator['extname'])
             self.logger.warning(message)
-            return HttpNotFound()
+            return NotFound()
 
         return desc
 
     def get_route_map(self, route_path):
         # 命中
         hit_route = None
-        for root_path in self.context.routes_map:
+        for root_path in self.config.routes_map:
             if route_path.startswith(root_path):
-                hit_route = root_path, self.context.routes_map[root_path]
+                hit_route = root_path, self.config.routes_map[root_path]
                 break
 
         if hit_route is None:
@@ -116,13 +116,13 @@ class RouteResolver:
         except Exception as e:
             message = 'Failed to load module "%s"' % module_name
             self.logger.error(message, e)
-            return HttpNotFound()
+            return NotFound()
 
         # 模块中也没有这个函数
         if not hasattr(entry_define, func_name):
             # 函数不存在，更新缓存
             self.entry_cache[func_name] = None
-            return HttpNotFound()
+            return NotFound()
 
         # 模块中有这个函数
         # 通过反射从模块加载函数
@@ -130,7 +130,7 @@ class RouteResolver:
         import inspect
         from . import Collector
         filename = inspect.getmodule(func).__file__
-        decorator = Collector.get(self.context.app_id).resolve_routes(filename, func_name)
+        decorator = Collector.get(self.config.app_id).resolve_routes(filename, func_name)
 
         if decorator is None:
             msg = '%s\n\tDecorator "@route" not found on function "%s", did you forgot it ?' % (
@@ -140,7 +140,7 @@ class RouteResolver:
             self.logger.warning(msg)
             # 没有配置装饰器@route，则认为函数不可访问，更新缓存
             self.entry_cache[func_name] = None
-            return HttpNotFound()
+            return NotFound()
 
         func_desc = FunctionDescription(func)
         func_desc.decorator = decorator
