@@ -1,4 +1,5 @@
 import inspect
+import re
 
 
 def load_module(module_name: str, level=0):
@@ -23,12 +24,9 @@ def load_module(module_name: str, level=0):
 def get_func_info(func):
     source_lines = inspect.getsourcelines(func)
     line = source_lines[1]
-    return 'File "%s", line %d, in %s' % (
+    return 'File "%s", line %d, code %s' % (
         inspect.getmodule(func).__file__,
-        # 此处的 line 是从 0 开始计算的，
-        # 而在编辑器中，或者说从开发者角度来看，应该是从 1 开始计算
-        # 所以 +1 以修正行号的正确性
-        line + 1,
+        line,
         func.__name__
     )
 
@@ -49,3 +47,21 @@ def get_ip_list():
             ips.append(ip)
 
     return ips
+
+
+def get_exception_info(message: str, e: Exception = None):
+    messages = []
+    if e:
+        tb = e.__traceback__
+
+        while tb:
+            msg = str(tb.tb_frame.f_code)
+            match = re.match(r'^<code object (?P<name>([a-zA-Z0-9_]+?)) at.+?, file (?P<file>(.+?)),.+$', msg)
+            if match:
+                msg = 'File %s, line %s, code %s' % (match.group('file'), tb.tb_frame.f_lineno, match.group('name'))
+            messages.append(msg)
+
+            tb = tb.tb_next
+
+    messages.append(message)
+    return '\n\t'.join(messages)
